Generated documentation for <notebook_utils>.

**Use**:
**Created Date**: 08/06/2021

# Developers (Contribution Guidelines)

Documentation for contributing to the model

## Environment Setup

Run `python setup.py test`

# End users

## Environment Setup

- Ensure correct Python installed `python -V` should > `3.7`
- Setup Virtual Python environment and activate
- Run `python setup.py install`
